document.addEventListener("DOMContentLoaded", initializeInterestButtons);

function initializeInterestButtons() {
  const menuButtons = document.querySelectorAll(".interest-menu-button");
  
  menuButtons.forEach((button) => {
    button.addEventListener("click", (e) => {
      e.stopPropagation();
      const menu = button.nextElementSibling;
      menu.classList.toggle("hidden");
    });

    const options = button.nextElementSibling.querySelectorAll(".interest-option");
    options.forEach((option) => {
      option.addEventListener("click", handleInterestOptionClick);
    });
  });
}

async function handleInterestOptionClick(e) {
  e.preventDefault();
  const button = this.closest('.relative').querySelector('.interest-menu-button');
  const reference = button.dataset.propertyReference;
  const status = this.dataset.status;
  const isNotInterested = status === "not_interested";

  try {
    const response = await fetch(`/api/properties/${reference}/interest`, {
      method: isNotInterested ? "POST" : "DELETE",
      headers: {
        "Content-Type": "application/json",
        "x-csrf-token": document.querySelector("meta[name='csrf-token']").content,
      },
    });

    const data = await response.json();

    if (response.ok) {
      const menu = this.closest('.interest-menu');
      const ticks = menu.querySelectorAll(".interest-tick");
      ticks.forEach(tick => tick.classList.add("invisible"));
      this.querySelector(".interest-tick").classList.remove("invisible");
      
      menu.classList.add("hidden");
      
      // Fetch and update content
      const propertiesContainer = document.getElementById("properties");
      propertiesContainer.innerHTML = await fetch(window.location.pathname)
        .then(response => response.text())
        .then(html => {
          const doc = new DOMParser().parseFromString(html, 'text/html');
          return doc.getElementById("properties").innerHTML;
        });
      
      // Initialize both sets of buttons
      document.dispatchEvent(new Event('DOMContentLoaded'));
      
      showFlashMessage("success", data.message);
    } else {
      showFlashMessage("error", data.error);
    }
  } catch (error) {
    console.error("Error:", error);
    showFlashMessage("error", "Something went wrong");
  }
}

document.addEventListener("click", () => {
  document.querySelectorAll(".interest-menu").forEach(menu => {
    menu.classList.add("hidden");
  });
});

function showFlashMessage(type, message) {
  const flashContainer = document.createElement("div");
  flashContainer.className = `flash-message ${type}`;
  flashContainer.textContent = message;

  document.body.appendChild(flashContainer);

  setTimeout(() => {
    flashContainer.style.animation = "fadeOut 0.3s ease-out";
    flashContainer.addEventListener("animationend", () => flashContainer.remove());
  }, 3000);
}