document.addEventListener("DOMContentLoaded", function () {
  const calculateButton = document.getElementById("calculate_button");
  const calculatedPriceField = document.getElementById("calculated_price");
  const priceField = document.getElementById("price"); // Price field to be updated

  if (calculateButton) {
    calculateButton.addEventListener("click", async function () {
      try {
        const path = window.location.pathname;
        let typeValue, propertyTypeValue, areaValue, roomCountValue, floorValue, floorCountValue;

        // Check URL to determine page context
        if (path.startsWith("/properties/") && (path.includes("/new") || path.includes("/edit"))) {
          // New property creation page
          typeValue = document.getElementById("type").value;
          propertyTypeValue = document.getElementById("property_type").value;
          areaValue = parseFloat(document.getElementById("area").value.trim());
          roomCountValue = parseInt(document.getElementById("room_count").value.trim(), 10);
          floorValue = parseInt(document.getElementById("floor").value.trim(), 10);
          floorCountValue = parseInt(document.getElementById("floor_count").value.trim(), 10);
        } else if (path.startsWith("/properties/") && !path.includes("/new")  && !path.includes("/edit")) {
          // View/edit property page
          typeValue = document.getElementById("type").textContent.trim().toLowerCase();
          propertyTypeValue = document.getElementById("property_type").textContent.trim().toLowerCase();
          areaValue = parseFloat(document.getElementById("area").textContent.trim());
          roomCountValue = parseInt(document.getElementById("room_count").textContent.trim(), 10);
          floorValue = parseInt(document.getElementById("floor").textContent.trim(), 10);
          floorCountValue = parseInt(document.getElementById("floor_count").textContent.trim(), 10);
        } else {
          alert("Unknown page. Cannot calculate price.");
          return;
        }

        console.log({
          type: typeValue,
          property_type: propertyTypeValue,
          area: areaValue,
          room_count: roomCountValue,
          floor: floorValue,
          floor_count: floorCountValue,
        });

        // Validate required fields
        if (
          !typeValue ||
          !propertyTypeValue ||
          isNaN(areaValue) ||
          isNaN(roomCountValue) ||
          isNaN(floorValue) ||
          isNaN(floorCountValue)
        ) {
          alert("Please fill in all fields with valid values to calculate the price.");
          return;
        }

        const response = await fetch("/api/properties/calculate_price", {
          method: "POST",
          headers: {
            "Content-Type": "application/json",
            "x-csrf-token": document.querySelector("meta[name='csrf-token']").content,
          },
          body: JSON.stringify({
            type: typeValue,
            property_type: propertyTypeValue,
            area: areaValue,
            room_count: roomCountValue,
            floor: floorValue,
            floor_count: floorCountValue,
          }),
        });

        if (response.ok) {
          const data = await response.json();
          console.log("Calculated Price:", data.calculated_price);

          // Update both calculated_price and price fields
          calculatedPriceField.value = data.calculated_price;
          if (priceField) {
            priceField.value = data.calculated_price;
          }
        } else {
          const errorData = await response.json();
          alert(`Error calculating price: ${errorData.error || "Unknown error"}`);
        }
      } catch (error) {
        console.error("Error during price calculation:", error);
        alert("An error occurred while calculating the price. Please try again.");
      }
    });
  }
});
