document.addEventListener("DOMContentLoaded", function () {
    const statusButton = document.querySelector(".status-dropdown-button");
    const statusMenu = document.querySelector(".status-dropdown-menu");
    const statusOptions = document.querySelectorAll(".status-option");
    const statusText = document.getElementById("property-status-text");
  
    if (statusButton) {
      // Toggle dropdown
      statusButton.addEventListener("click", function () {
        statusMenu.classList.toggle("hidden");
      });
  
      // Close dropdown when clicking outside
      document.addEventListener("click", function (event) {
        if (!statusButton.contains(event.target) && !statusMenu.contains(event.target)) {
          statusMenu.classList.add("hidden");
        }
      });
  
      // Handle status updates
      statusOptions.forEach((option) => {
        option.addEventListener("click", async function () {
          const reference = statusButton.dataset.propertyReference;
          const newStatus = this.dataset.status;
  
          try {
            const response = await fetch(`/api/properties/${reference}/status`, {
              method: "POST",
              headers: {
                "Content-Type": "application/json",
                "x-csrf-token": document.querySelector("meta[name='csrf-token']").content,
              },
              body: JSON.stringify({ state: newStatus }),
            });
  
            const data = await response.json();
  
            if (response.ok) {
              // Update the status text
              let displayStatus = data.state.charAt(0).toUpperCase() + newStatus.slice(1);
              if (newStatus === "unavailable") {
                displayStatus = statusButton.dataset.propertyType === "rent" ? "Rented" : "Sold";
              }
              statusText.textContent = displayStatus;
              
              // Hide the dropdown
              statusMenu.classList.add("hidden");
              // Show success message
              showFlashMessage("success", "Status updated successfully");
            } else {
              showFlashMessage("error", data.error || "Failed to update status");
            }
          } catch (error) {
            console.error("Error:", error);
            showFlashMessage("error", "Something went wrong");
          }
        });
      });
    }
  });
  
  function showFlashMessage(type, message) {
    const flashContainer = document.createElement("div");
    flashContainer.className = `flash-message ${type}`;
    flashContainer.textContent = message;
  
    document.body.appendChild(flashContainer);
  
    setTimeout(() => {
      flashContainer.style.animation = "fadeOut 0.3s ease-out";
      flashContainer.addEventListener("animationend", () => flashContainer.remove());
    }, 3000);
  }