defmodule UserProfileContext do
  use WhiteBread.Context
  use Hound.Helpers
  alias PropTrackr.Accounts
  alias PropTrackr.Repo
  alias PropTrackr.Accounts.User

  scenario_starting_state fn _state ->
    Ecto.Adapters.SQL.Sandbox.checkout(PropTrackr.Repo)
    Ecto.Adapters.SQL.Sandbox.mode(PropTrackr.Repo, {:shared, self()})
    Hound.start_session()
    %{}
  end

  scenario_finalize fn _status, _state ->
    Ecto.Adapters.SQL.Sandbox.checkin(PropTrackr.Repo)
    Hound.end_session()
  end

  given_ ~r/^there exists following accounts$/, fn state, %{table_data: table} ->
    table                                                                                
    |> Enum.map(fn user_details -> User.changeset(%User{}, user_details) end)                            
    |> Enum.each(fn changeset -> Repo.insert!(changeset) end)

    existing_user = List.first(table)

    {
      :ok,
      state
      |> Map.put(:user, existing_user)
    }
  end

  and_ ~r/^I am logged in$/, fn state ->
    setup_session(state[:user][:email], state[:user][:password])
    {:ok, state}
  end

  when_ ~r/^I go to the profile page$/, fn state ->
    navigate_to("/me")
    {:ok, state}
  end

  then_ ~r/^I should see my profile details$/, fn state ->
    assert visible_in_page? ~r/#{state[:user][:name]} #{state[:user][:surname]}'s profile/
    assert visible_in_page? ~r/#{state[:user][:email]}/
    assert visible_in_page? ~r/#{state[:user][:phone_number]}/
    assert visible_in_page? ~r/#{state[:user][:bio]}/
    assert visible_in_page? ~r/#{state[:user][:birth_date]}/
    {:ok, state}
  end

  given_ ~r/^I am not logged in$/, fn state ->
    navigate_to("/logout")
    {:ok, state}
  end

  then_ ~r/^I should see an error message$/, fn state ->
    assert visible_in_page? ~r/You are not logged in!/
    {:ok, state}
  end

  and_ ~r/^I should be redirected to the login page$/, fn state ->
    assert current_path() == "/login"
    {:ok, state}
  end

  defp setup_session(email, password) do
    navigate_to("/login")
    fill_field({:id, "email"}, email)
    fill_field({:id, "password"}, password)
    click({:id, "login_button"})
  end

end
