defmodule PropTrackrWeb.InterestController do
  use PropTrackrWeb, :controller

  import Ecto.Query
  alias PropTrackr.Repo
  alias PropTrackr.Properties.Property
  alias PropTrackr.NotInterested

  def create(conn, %{"reference" => reference}) do
    current_user = conn.assigns.current_user

    if current_user == nil do
      conn
      |> put_status(:unauthorized)
      |> json(%{error: "You must be logged in"})
    else
      case Repo.one(from p in Property, where: p.reference == ^reference) do
        nil ->
          conn
          |> put_status(:not_found)
          |> json(%{error: "Property not found"})

        property ->
          if property.user_id == current_user.id do
            conn
            |> put_status(:forbidden)
            |> json(%{error: "Cannot mark own property as not interested"})
          else
            changeset = %NotInterested{}
            |> NotInterested.changeset(%{
              user_id: current_user.id,
              property_id: property.id
            })

            case Repo.insert(changeset) do
              {:ok, _} -> json(conn, %{message: "Marked as not interested"})
              {:error, _} ->
                conn
                |> put_status(:unprocessable_entity)
                |> json(%{error: "Already marked as not interested"})
            end
          end
      end
    end
  end

  def delete(conn, %{"reference" => reference}) do
    current_user = conn.assigns.current_user

    if current_user == nil do
      conn
      |> put_status(:unauthorized)
      |> json(%{error: "You must be logged in"})
    else
      case Repo.one(from p in Property, where: p.reference == ^reference) do
        nil ->
          conn
          |> put_status(:not_found)
          |> json(%{error: "Property not found"})

        property ->
          case Repo.one(from n in NotInterested,
            where: n.user_id == ^current_user.id and n.property_id == ^property.id) do
            nil ->
              conn
              |> put_status(:not_found)
              |> json(%{error: "Already marked as interested"})

            not_interested ->
              case Repo.delete(not_interested) do
                {:ok, _} -> json(conn, %{message: "Marked as interested"})
                {:error, _} ->
                  conn
                  |> put_status(:internal_server_error)
                  |> json(%{error: "Failed to update"})
              end
          end
      end
    end
  end
end
