defmodule PropTrackrWeb.OwnerProfileController do
  use PropTrackrWeb, :controller

  import Ecto.Query, only: [from: 2]
  alias PropTrackr.Repo
  alias PropTrackr.Accounts.User
  alias PropTrackr.Properties.Property
  alias PropTrackr.Favorites.Favorite

  def show(conn, %{"id" => user_id}) do
    has_properties = Repo.exists?(
      from p in Property,
      where: p.user_id == ^user_id and p.state == :available
    )

    if !has_properties do
      conn
      |> put_flash(:error, "Profile not accessible or does not exist.")
      |> redirect(to: ~p"/")
    else
      case Repo.get(User, user_id) do
        nil ->
          conn
          |> put_flash(:error, "User not found.")
          |> redirect(to: ~p"/")

        owner ->
          current_user = conn.assigns.current_user
          current_user_id = current_user && current_user.id

          properties = Repo.all(
            from p in Property,
            where: p.user_id == ^owner.id and p.state == :available,
            order_by: [desc: p.inserted_at],
            preload: [:photos],
            select: p
          )

          favorites = if current_user do
            Repo.all(
              from f in Favorite,
              where: f.user_id == ^current_user_id,
              select: f.property_id
            )
          else
            []
          end

          render(conn, "show.html",
            owner: owner,
            properties: properties,
            favorites: favorites
          )
      end
    end
  end
end
