defmodule PropTrackrWeb.LoginControllerTest do
  use PropTrackrWeb.ConnCase
  alias PropTrackr.Accounts.User
  alias PropTrackr.Repo

  @valid_attrs %{email: "test.user@gmail.com", password: "password123"}
  @invalid_email_attrs %{email: "invalid.email@gmail.com", password: "testing"}
  @invalid_password_attrs %{email: "test.user@gmail.com", password: "invalid_password"}

  @password "password123"

  setup do
    user = %User{
      name: "Test",
      surname: "User",
      birth_date: ~D[2000-01-01],
      phone_number: "000",
      bio: "Yo",
      email: "test.user@gmail.com",
      password: @password,
      confirm_password: @password,
      hashed_password: Bcrypt.hash_pwd_salt(@password)
    }
    Repo.insert!(user)

    :ok
  end

  test "Unauthenticated user should be able to log in with correct credentials and be redirected to the homepage", %{conn: conn} do
    conn = conn |> post("/login", @valid_attrs)
    assert redirected_to(conn) == "/"
    conn = get conn, redirected_to(conn)
    assert html_response(conn, 200)
    assert get_flash(conn, :info) =~ ~r/Successfully logged in!/
    assert get_session(conn, :user_id)
  end

  test "Unauthenticated user should receive an error with invalid email", %{conn: conn} do
    conn = conn |> post("/login", @invalid_email_attrs)
    assert html_response(conn, 200)
    assert get_flash(conn, :error) =~ ~r/Given email does not exist!/
  end

  test "Unauthenticated user should receive an error with invalid password", %{conn: conn} do
    conn = conn |> post("/login", @invalid_password_attrs)
    assert html_response(conn, 200)
    assert get_flash(conn, :error) =~ ~r/Invalid credentials!/
  end
end
